$DEBUG
C***********************************************************************
C
      SUBROUTINE CH4
C
C***********************************************************************
C
C                --  THE METHANE EMISSION SUBROUTINE  --
C
C THIS MODULE CALCULATES GROSS METHANE EMISSIONS TO THE ATMOSPHERE IN A
C GIVEN PERIOD FROM ENERGY PRODUCTION AND CONSUMPTION DATA
C
C   INTEGER INPUTS:  NKKL, NL  
C   REAL INPUTS:     CHI, EFJKL, EFJL, ESIL1M, ESIL2M, SVENTL,SFEDIL,
C                    SFLRL,SDOCLM,SAXLM, SLDFLM
C
C   INTERNAL INTEGERS:  ICOAL, IGASP, IGASV, IGASP, IOIL, IBIO,ILDF
C       
C
C   REAL OUTPUTS:    CH4IL, CH4IM, CH4LM, CH4M
C
C   SUBROUTINES CALLED:  NONE
C
C   CODED BY
C       ACE BARNS                      LATEST REVISION:
C       8 AUGUST 1988                  4 SEPTEMBER 1988          
C                                      22 AUGUST 1989 TO INCLUDE REGIONAL
C                                      SHARES FOR CHILM, SDOCLM, SAXLM,
C                                      AND SLDFLM   
C
C***********************************************************************
C
C  MAKE ALL REAL VARIABLES DOUBLE PRECISION
C
      IMPLICIT   REAL*8 (A-H,O-Z),   INTEGER (I-N)
C
C COMMON BLOCKS
C
$INCLUDE: 'COMMON.FOR'
C
C  --  LOCAL VARIABLES
C
      REAL*8   A,B,C,D,CH4IL(7,9),SV  
      INTEGER  R(30)
C
C  --  INITIALIZE HEADERS
C
      R(1)='USA '
      R(2)='    '
      R(3)='    '
      R(4)='W EU'
      R(5)='R + '
      R(6)='CAN '
      R(7)='OECD'
      R(8)=' PAC'
      R(9)='IFIC'
      R(10)='USSR'
      R(11)='/E. '
      R(12)='EUR.'
      R(13)='CHIN'
      R(14)='A/ET'
      R(15)='.AL.'
      R(16)='MIDD'
      R(17)='LE E'
      R(18)='AST '
      R(19)='AFRI'
      R(20)='CA  '
      R(21)='    '
      R(22)='LATI'
      R(23)='N AM'
      R(24)='ER  '
      R(25)='S.&E'
      R(26)='. AS'
      R(27)='IA  '
      R(28)='ALL '
      R(29)='REGI'
      R(30)='ONS '
C
C
C -- INITIALIZE SOURCE DESIGNATORS, ZERO CH4 TOTALS, AND SET IUNIT VALUE
C
      NCH4=7
      IUNIT=IOUNIT
      ICOAL=1
      IGASP=1
      IGASV=2
      IGAST=3
      IOIL=2
      IBIO=4
      ILDF=5
C     SV=0.1D00
      CH4M(M)=0.D0
      DO 10 I=1,NCH4
         CH4IM(I,M)=0.D0
C  
   10 CONTINUE
C
      T=(M-1)*NJUMP
C
C
C     -----COMMENCE REGIONAL DO-LOOP---------- 
C
C
      DO 100 L=1,NL
C
C  --  INTERPOLATE VENTED GAS PARAMETER VALUES
C
          SV=XNTERP(SVENTL(L,1),SVENTL(L,2),SVENTL(L,3),T)
C      
C
C           -------------------------------------------------
C           --  COMPUTE EMISSIONS FROM ENERGY CONSUMPTION  --
C           -------------------------------------------------
         IF (NKKL(L)-2)   52,50,52
   50    CH4IL(5,L)=EFJKL(1,1,L)*(1.D0-SFEDIL(1,L))*CHILM(IOIL,L,M)*
     &        SAXLM(L,M)
        GOTO 53                            
   52    CH4IL(5,L)=EFJKL(1,3,L)*(1.D0-SFEDIL(1,L))*CHILM(IOIL,L,M)*
     &        SAXLM(L,M)
   53   CONTINUE
            CH4IL(4,L)=EFJL(2,L)*(1.D0-SFEDIL(2,L))*CHI(IGAST)*
     &        SGAST(L,M)
            CH4IL(6,L)=EBIOL(L)*(PILM(1,L,M)/PILM(1,L,1))**
     &        RPBIOL(L)*((YLM(L,M)/ZLM(L,M))/(YLM(L,1)/ZLM(L,1)))**          
   
     &        RYBIOL(L)*(ZLM(L,M)/ZLM(L,1))*CHI(IBIO)
C
C
C            ------------------------------------------------
C            --  COMPUTE EMISSIONS FROM ENERGY PRODUCTION  --
C            ------------------------------------------------
         CH4IL(2,L)=ESIL1M(2,L,M)* CHI(IGASP)*SGASP(L,M)
         CH4IL(1,L)=ESIL1M(3,L,M)*CHILM(ICOAL,L,M)
         CH4IL(3,L)=SV*SFLRL(L)/(1.D0-SFLRL(L))*ESIL(2,L)
     &                   *CHI(IGASV)
C
C              --------------------------------------------------
C              -- COMPUTE EMISSIONS FROM SOLID WASTE LANDFILLS --
C              --------------------------------------------------
C
         CH4IL(7,L)=EBRSLM(L,M)*SWASL(L)*CLDF*SLDFLM(L,M)*SDOCLM(L,M)
     &    *CHI(ILDF)              
 
C
C            NOTE: EBRSLM IS THAT FRACTION OF RESIDUAL WASTE
C            BIOMASS WHICH IS NOT USED DIRECTLY AS MODERN BIOMASS.
C            IT IS COMPUTED IN THE SSSS SUBROUTINE.
C            SWASL IS FRACTION OF ELDFLM AVAILABLE FOR LANDFILLS.
C
C                 -------------------------------------
C                 --  TOTAL REGIONAL CH4 PRODUCTION  --
C                 -------------------------------------
C
         CH4LM(L,M)=0.D0
         DO 70 I=1,NCH4
            CH4LM(L,M)=CH4LM(L,M)+CH4IL(I,L)
            CH4IM(I,M)=CH4IM(I,M)+CH4IL(I,L)
   70    CONTINUE
         CH4M(M)=CH4M(M)+CH4LM(L,M)
  100 CONTINUE
C
C         ----END REGIONAL DO-LOOP--------
C
C  ---OUTPUT OPTION CONTROL FOR THE CO2 RESULTS----
C
      IF (NOPT(8) .EQ. 1) GO TO 110
C
C                         ---------------------
C                         --  PRINT RESULTS  --
C                         ---------------------
      NYR=1950+NJUMP*M
      WRITE(JUNIT,1000)   NYR
      WRITE(JUNIT,1010)
      WRITE(JUNIT,1020)
      WRITE(JUNIT,1030)
      WRITE(JUNIT,1040)
      WRITE(JUNIT,1060)
      WRITE(JUNIT,1070)
      DO 200 L=1,NL
         LA=1+3*(L-1)
         LB=LA+2
         WRITE(JUNIT,1080)  (R(LL),LL=LA,LB),(CH4IL(I,L),I=1,7),
     &                       CH4LM(L,M)
  200 CONTINUE
      WRITE(JUNIT,1070)
      WRITE(JUNIT,1090)
      L=NL+1
      LA=1+3*(L-1)
      LB=LA+2
      WRITE(JUNIT,1080)  (R(LL),LL=LA,LB),(CH4IM(I,M),I=1,7),CH4M(M)
 1000 FORMAT(1X,27X,I4,1X,'CH4 EMISSIONS REPORT')
 1010 FORMAT(1X,27X,'*************************')
 1020 FORMAT('0',20X,'CH4 EMISSIONS BY REGION AND PRIMARY SOURCE'
     &)
 1030 FORMAT(1X,25X,'UNITS:  10**6 TONNES OF METHANE')
 1040 FORMAT('0',16X,'COAL',3X,'GAS',5X,'GAS',5X,'GAS',5X,'AUTO',
     &3X,'BIOMAS',3X,'LAND')
 1060 FORMAT(1X,'REGION',8X,'PROD''N',2X,'PROD''N',2X,'VENT''G',2X,    
     &'TRNMSN',2X,'EXHAUST',1X,'BURN''G',3X,'FILL',3X,'TOTAL')
 1070 FORMAT(1X,12('-'),8(2X,6('-')))
 1080 FORMAT(1X,3A4,8(2X,F6.2))
 1090 FORMAT(1X)
C
  110 CONTINUE
C
      RETURN
      END
